#
# spec file for package python-aioquic
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-aioquic
Version:        0.9.25
Release:        2.4
Summary:        Python implementation of QUIC and HTTP/3
License:        BSD-3-Clause
URL:            https://github.com/aiortc/aioquic
Source:         https://files.pythonhosted.org/packages/source/a/aioquic/aioquic-%{version}.tar.gz
# PATCH-FIX-UPSTREAM gh#aiortc/aioquic#452
Patch0:         support-service-identity-24.patch
BuildRequires:  %{python_module devel >= 3.7}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  pkgconfig
BuildRequires:  python-rpm-macros
BuildRequires:  pkgconfig(openssl)
Requires:       python-certifi
Requires:       python-cryptography >= 3.1
Requires:       python-pyOpenSSL >= 22
Requires:       python-pylsqpack >= 0.3.3
Requires:       python-service_identity
# SECTION test requirements
BuildRequires:  %{python_module service_identity}
BuildRequires:  %{python_module certifi}
BuildRequires:  %{python_module cryptography >= 2.5}
BuildRequires:  %{python_module pyOpenSSL >= 20}
BuildRequires:  %{python_module pylsqpack >= 0.3.3}
# /SECTION
%python_subpackages

%description
A library for the QUIC network protocol in Python. It features a minimal TLS
1.3 implementation, a QUIC stack and an HTTP/3 stack.

%prep
%autosetup -p1 -n aioquic-%{version}

%build
export CFLAGS="%{optflags}"
%pyproject_wheel

%install
%pyproject_install
%{python_expand rm %{buildroot}%{$python_sitearch}/aioquic/*.c
%fdupes %{buildroot}%{$python_sitearch}
}

%check
%pyunittest_arch -v

%files %{python_files}
%doc README.rst
%license LICENSE
%{python_sitearch}/aioquic
%{python_sitearch}/aioquic-%{version}.dist-info

%changelog
* Thu Jan 25 2024 Steve Kowalik <steven.kowalik@suse.com>
- Drop patch cryptography.patch:
  * No longer required.
- Add patch support-service-identity-24.patch:
  * Support service-identity >= 24
- Switch to pyproject macros.
* Sat Jan 20 2024 Dirk Müller <dmueller@suse.com>
- update to 0.9.25:
  * Add parsing and serialization for certificate requests
  * Allow clients to authenticate with servers using a certificate
  * Close connection if client's first INITIAL contains no CRYPTO
  * Exclude binary packet captures from spelling check
  * Added support for cubic congestion control (RFC9438)
  * Drop httpbin from HTTP/3 server demo
  * Raise a TLS alert if parsing a message causes a BufferReadError
* Thu Dec 14 2023 Petr Gajdos <pgajdos@suse.com>
- update to 0.9.23
  * no upstream changelog found
* Thu Sep  7 2023 Dirk Müller <dmueller@suse.com>
- update to 0.9.21:
  * http3_client: :path should not be empty
  * Move project metadata to pyproject.toml
  * Fix X509StoreContextError usage for pyOpenSSL >= 22
  * Test against Python 3.11
  * Use function parameters instead of global args in examples
* Tue Jul  4 2023 ecsos <ecsos@opensuse.org>
- Add %%{?sle15_python_module_pythons}
* Wed Jan 25 2023 Daniel Garcia <daniel.garcia@suse.com>
- Update to v0.9.20
  * free AEADObject's and HeaderProtectionObject's memory
  * free BufferObject’s memory
  * Enable IPv4/IPv6 dual stack support on Windows
  * [docs] add a logo, stop mocking libraries
  * [docs] test that documentation can be built without warnings
  * [tests] clarify the various handshake loss test cases
  * [connection] retransmit CRYPTO to speedup handshake completion
  * [examples] update DoQ examples for more recent drafts (fixes: #224)
  * [lint] run mypy on each CI run
- 0.9.19
  * [tls] use PyOpenSSL to validate certificate
  * [qa] set better names for our C modules
  * [package] drop dependency on "dataclasses" package
  * [package] update cryptography requirement to >= 3.1
  * [qa] fix some type annotations
  * [http3] advertise support for extended CONNECT
  * [examples] make HTTP/3 client set content-length (fixes: #241)
  * [package] fix macosx arm64 wheels
- 0.9.18
  * [examples] add sec-webtransport-http3-draft to server response
  * [package] update OpenSSL to 1.1.1m
  * [tests] rewrite asyncio tests as coroutines
  * [qa] reformat code using updated `black`
  * [qa] tell git to ignore virtual environments
  * http3_client.py: correct error code for connection close
  * [webtransport] make H3_DATAGRAM value uppercase
  * [webtransport] update H3_DATAGRAM value
  * [readme] update minimal Python version
  * [examples] don't sent HTTP/3 DATA if there is no request body
* Thu Jan  6 2022 Ben Greiner <code@bnavigator.de>
- Update to v0.9.17
  * no release notes
- Unpin cryptography (who pins security software to old versions!?)
  * Add cryptography.patch
- Skip python36: this is a python310 fix and could be needed before
  the global drop
* Tue Feb 23 2021 John Vandenberg <jayvdb@gmail.com>
- Update to v0.9.7
* Tue Feb 18 2020 John Vandenberg <jayvdb@gmail.com>
- Initial spec for v0.8.5
